diff --git a/addons/ooh323c/src/ooasn1.h b/addons/ooh323c/src/ooasn1.h
index 8355c54d05fe824cfc54f0a294296c274ac6de56..4fee6211606fc335d2ab808c12dec7669d171cc2 100644
--- a/addons/ooh323c/src/ooasn1.h
+++ b/addons/ooh323c/src/ooasn1.h
@@ -664,7 +664,7 @@ EXTERN int setPERBufferUsingCtxt (OOCTXT* pTarget, OOCTXT* pSource);
 /**
  * This function adds an integer parameter to an error information structure.
  * Parameter substitution is done in much the same way as it is done in C
- * printf statments. The base error message specification that goes along with
+ * printf statements. The base error message specification that goes along with
  * a particular status code may have variable fields built in using '%'
  * modifiers. These would be replaced with actual parameter data.
  *
@@ -680,7 +680,7 @@ EXTERN int errAddIntParm (ASN1ErrInfo* pErrInfo, int errParm);
 /**
  * This function adds an string parameter to an error information structure.
  * Parameter substitution is done in much the same way as it is done in C
- * printf statments. The base error message specification that goes along with
+ * printf statements. The base error message specification that goes along with
  * a particular status code may have variable fields built in using '%'
  * modifiers. These would be replaced with actual parameter data.
  *
@@ -697,7 +697,7 @@ EXTERN int errAddStrParm (ASN1ErrInfo* pErrInfo,
 /**
  * This function adds an unsigned integer parameter to an error information
  * structure. Parameter substitution is done in much the same way as it is done
- * in C printf statments. The base error message specification that goes along
+ * in C printf statements. The base error message specification that goes along
  * with a particular status code may have variable fields built in using '%'
  * modifiers. These would be replaced with actual parameter data.
  *
diff --git a/res/res_config_ldap.c b/res/res_config_ldap.c
index 6137236108979eb465b267064a39039e468d620c..91be91a752020a57af81f528009a2938f3b68ab9 100644
--- a/res/res_config_ldap.c
+++ b/res/res_config_ldap.c
@@ -89,7 +89,7 @@ struct category_and_metric {
 	int metric;
 	const char *variable_name;
 	const char *variable_value;
-	int var_metric; /*!< For organizing variables (particularly includes and switch statments) within a context */
+	int var_metric; /*!< For organizing variables (particularly includes and switch statements) within a context */
 };
 
 /*! \brief Table configuration
@@ -1032,7 +1032,7 @@ static struct ast_variable *realtime_ldap(const char *basedn,
 
 /*! \brief See Asterisk doc
  *
- * this function will be called for the switch statment if no match is found with the realtime_ldap function(i.e. it is a failover);
+ * this function will be called for the switch statement if no match is found with the realtime_ldap function(i.e. it is a failover);
  * however, the ast_load_realtime wil match on wildcharacters also depending on what the mode is set to
  * this is an area of asterisk that could do with a lot of modification
  * I think this function returns Realtime dynamic objects
diff --git a/main/db.c b/main/db.c
index bf730207cfc3e287ba98547fcbc6970b13401494..4d1b37242d73f9bf900c6fb69b209d947e675000 100644
--- a/main/db.c
+++ b/main/db.c
@@ -191,8 +191,8 @@ static void clean_statements(void)
 
 static int init_statements(void)
 {
 	/* Don't initialize create_astdb_statment here as the astdb table needs to exist
 	 * brefore these statments can be initialized */
 	return init_stmt(&get_stmt, get_stmt_sql, sizeof(get_stmt_sql))
 	|| init_stmt(&del_stmt, del_stmt_sql, sizeof(del_stmt_sql))
 	|| init_stmt(&deltree_stmt, deltree_stmt_sql, sizeof(deltree_stmt_sql))
@@ -347,7 +347,7 @@ int ast_db_put(const char *family, const char *key, const char *value)
 		ast_log(LOG_WARNING, "Couldn't bind value to stmt: %s\n", sqlite3_errmsg(astdb));
 		res = -1;
 	} else if (sqlite3_step(put_stmt) != SQLITE_DONE) {
-		ast_log(LOG_WARNING, "Couldn't execute statment: %s\n", sqlite3_errmsg(astdb));
+		ast_log(LOG_WARNING, "Couldn't execute statement: %s\n", sqlite3_errmsg(astdb));
 		res = -1;
 	}
 
@@ -191,8 +191,8 @@ static void clean_statements(void)
 static int init_statements(void)
 {
-	/* Don't initialize create_astdb_statment here as the astdb table needs to exist
-	 * brefore these statments can be initialized */
+	/* Don't initialize create_astdb_statement here as the astdb table needs to exist
+	 * brefore these statements can be initialized */
 	return init_stmt(&get_stmt, get_stmt_sql, sizeof(get_stmt_sql))
 	|| init_stmt(&del_stmt, del_stmt_sql, sizeof(del_stmt_sql))
diff --git a/utils/astdb2sqlite3.c b/utils/astdb2sqlite3.c
index ba35f9360cce6a2eed2ae14df150f9d7f4e3d101..fa00bc984d4e2790fc06aff5bf013adef72edc56 100644
--- a/utils/astdb2sqlite3.c
+++ b/utils/astdb2sqlite3.c
@@ -95,7 +95,7 @@ static int db_put_raw(const char *key, size_t keylen, const char *value, size_t
 		fprintf(stderr, "Couldn't bind value to stmt: %s\n", sqlite3_errmsg(astdb));
 		res = -1;
 	} else if (sqlite3_step(put_stmt) != SQLITE_DONE) {
-		fprintf(stderr, "Couldn't execute statment: %s\n", sqlite3_errmsg(astdb));
+		fprintf(stderr, "Couldn't execute statement: %s\n", sqlite3_errmsg(astdb));
 		res = -1;
 	}
 	sqlite3_reset(put_stmt);
@@ -168,8 +168,8 @@ static int db_create_astdb(void)
 
 static int init_statements(void)
 {
 	/* Don't initialize create_astdb_statment here as the astdb table needs to exist
 	 * brefore these statments can be initialized */
 	return init_stmt(&put_stmt, put_stmt_sql, sizeof(put_stmt_sql));
 }
@@ -168,8 +168,8 @@ static int db_create_astdb(void)
 static int init_statements(void)
 {
-	/* Don't initialize create_astdb_statment here as the astdb table needs to exist
-	 * brefore these statments can be initialized */
+	/* Don't initialize create_astdb_statement here as the astdb table needs to exist
+	 * brefore these statements can be initialized */
 	return init_stmt(&put_stmt, put_stmt_sql, sizeof(put_stmt_sql));
 }